@@ -1,5 +1,5 @@
 # flake8: noqa
-from .core import (
+from lexicographic_encoding.core import (
     lexpackb, lexunpackb,
     pack_unaryint, unpack_unaryint,
     pack_gammaint, unpack_gammaint,
@@ -11,8 +11,10 @@ from .core import (
     pack_none, unpack_none,
     pack_tuple, unpack_tuple,
     pack_list, unpack_list,
+    pack_set, unpack_set,
+    pack_dict, unpack_dict,
     pack_general,
     PACK_MAPPING, UNPACK_MAPPING,
 )
-from .utils import is_prefix_of
-from .exceptions import UnknownClassEncoder, UnknownClassDecoder
+from lexicographic_encoding.utils import is_prefix_of
+from lexicographic_encoding.exceptions import UnknownClassEncoder, UnknownClassDecoder
